==> ml_orchestrator-0.0.7b0.tar.gz: ml_orchestrator-0.0.7b0/ml_orchestrator/comp_parser.py <==
import dataclasses
from typing import Dict, List, Type

from ml_orchestrator.env_params import EnvironmentParams
from ml_orchestrator.meta_comp import MetaComponent
from ml_orchestrator.utils.field_utils import (
    get_param_meta_data,
    get_param_meta_data_str,
)

IMPORT_COMPOUND = "from kfp.dsl import *\nfrom typing import *\nfrom importlib.metadata import version\n"


@dataclasses.dataclass
class ComponentParser:
    add_imports: List[str] = dataclasses.field(default_factory=lambda: [])
    only_function: bool = False

    def create_function(self, component: MetaComponent) -> str:
        kfp_func_name = component.kfp_func_name
        component_variables = component.comp_vars()
        comp_class = component.__class__
        func_scope = "(\n\t" + ",\n\t".join(self.get_func_params(component_variables)) + "\n)"
        comp_scope = "(\n\t\t" + ",\n\t\t".join(self.get_comp_params(component_variables)) + "\n\t)"
        func_definition = self._format_function_definition(kfp_func_name, func_scope)
        import_compound = self._format_import_compound(comp_class)
        comp_init = f"comp = {comp_class.__name__}{comp_scope}"
        comp_run = "comp.execute()"
        str_func_body = "\n\t".join([import_compound, comp_init, comp_run])
        str_func = func_definition + "\n\t" + str_func_body
        return str_func

    def _format_function_definition(self, kfp_func_name: str, func_scope: str) -> str:
        return f"def {kfp_func_name}{func_scope}:"

    def _format_import_compound(self, comp_class: Type) -> str:
        return f"from {comp_class.__module__} import {comp_class.__name__}"

    @staticmethod
    def create_decorator(env: EnvironmentParams) -> str:
        dec_vars = env.comp_vars()
        prams = ComponentParser.get_func_params(dec_vars, with_typing=False)
        override_params = ComponentParser._get_decorator_override_params(prams)
        dec_scope = "(\n\t" + ",\n\t".join(override_params) + "\n)"
        dec_scope = ComponentParser.convert_to_format_str(dec_scope)
        func_definition = f"@component{dec_scope}"
        return func_definition

    @staticmethod
    def convert_to_format_str(text: str) -> str:
        new_text = text.replace(", '", ", f'").replace("['", "[f'")
        new_text = new_text.replace(', "', ', f"').replace('["', '[f"')
        return new_text

    @staticmethod
    def _get_decorator_override_params(prams: List[str]) -> List[str]:
        return [p for p in prams if "None" not in p]

    @staticmethod
    def get_func_params(comp_vars: Dict, with_typing: bool = True) -> List[str]:
        return [
            get_param_meta_data_str(*get_param_meta_data(k, v), with_typing=with_typing) for k, v in comp_vars.items()
        ]

    @staticmethod
    def get_comp_params(comp_vars: Dict) -> List[str]:
        return [f"{k.name}={k.name}" for k, v in comp_vars.items()]

    def write_to_file(self, filename: str, content: str) -> None:
        file_content = f"{IMPORT_COMPOUND}\n\n\n{content}"
        for imp in self.add_imports:
            file_content = f"{imp}\n{file_content}"
        file_content = f"# flake8: noqa: F403, F405, B006\n{file_content}"
        with open(filename, "w", encoding="utf-8") as f:
            f.write(file_content)

    def create_kfp_str(self, component: MetaComponent) -> str:
        decorator_str = self.create_decorator(component.env)
        decorator_str = decorator_str.replace(" = ", "=")
        function_str = self.create_function(component)
        if self.only_function:
            return function_str
        kfp_component_str = f"{decorator_str}\n{function_str}"
        kfp_component_str = kfp_component_str.replace("\t", "    ")
        return kfp_component_str + "\n"

    def parse_components_to_file(self, components: List[MetaComponent], filename: str) -> None:
        kfp_str = ""
        for component in components:
            kfp_str += self.create_kfp_str(component)
            kfp_str += "\n\n"

        self.write_to_file(filename, kfp_str)

==> ml_orchestrator-0.0.9b0.tar.gz: ml_orchestrator-0.0.9b0/ml_orchestrator/comp_parser.py <==
import dataclasses
from typing import List

from ml_orchestrator.comp_protocol.comp_protocol import ComponentProtocol
from ml_orchestrator.comp_protocol.func_parser import FunctionParser
from ml_orchestrator.env_params import EnvironmentParams
from ml_orchestrator.meta_comp import MetaComponent


@dataclasses.dataclass
class ComponentParser(FunctionParser):
    add_imports: List[str] = dataclasses.field(default_factory=lambda: [])
    only_function: bool = False

    @staticmethod
    def create_decorator(env: EnvironmentParams) -> str:
        dec_vars = env.comp_vars()
        prams = ComponentParser.get_func_params(dec_vars, with_typing=False)
        override_params = ComponentParser._get_decorator_override_params(prams)
        dec_scope = "(\n\t" + ",\n\t".join(override_params) + "\n)"
        dec_scope = ComponentParser.convert_to_format_str(dec_scope)
        func_definition = f"@component{dec_scope}"
        return func_definition

    @staticmethod
    def convert_to_format_str(text: str) -> str:
        new_text = text.replace(", '", ", f'").replace("['", "[f'")
        new_text = new_text.replace(', "', ', f"').replace('["', '[f"')
        return new_text

    @staticmethod
    def _get_decorator_override_params(prams: List[str]) -> List[str]:
        return [p for p in prams if "None" not in p]

    def create_kfp_str(self, component: MetaComponent) -> str:  # type: ignore
        function_str = super().create_kfp_str(component)  # type: ignore
        if self.only_function:
            return function_str
        decorator_str = self.create_decorator(component.env)
        decorator_str = decorator_str.replace(" = ", "=")
        kfp_component_str = f"{decorator_str}\n{function_str}"
        kfp_component_str = kfp_component_str.replace("\t", "    ")
        return kfp_component_str + "\n"

    def parse_components_to_file(self, components: List[ComponentProtocol], filename: str) -> None:
        kfp_str = self.create_kfp_file_str(components)
        self.write_to_file(filename, kfp_str)

    def write_to_file(self, filename: str, file_content: str) -> None:
        for imp in self.add_imports:
            file_content = f"{imp}\n{file_content}"
        return super().write_to_file(filename, file_content)
